@@ -29,9 +29,11 @@ subset(keyw$keywords, ngram > 1 & freq > 1)
 head(joboffer[, c("sentence_id", "lemma", "upos")], 10)
 
 ## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-sentences <- unique(joboffer[, c("sentence_id", "sentence")])
+library(udpipe)
+joboffer$textrank_id <- unique_identifier(joboffer, c("doc_id", "paragraph_id", "sentence_id"))
+sentences <- unique(joboffer[, c("textrank_id", "sentence")])
 terminology <- subset(joboffer, upos %in% c("NOUN", "ADJ"))
-terminology <- terminology[, c("sentence_id", "lemma")]
+terminology <- terminology[, c("textrank_id", "lemma")]
 head(terminology)
 
 ## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
@@ -51,7 +53,7 @@ cat(s, sep = "\n")
 library(textreuse)
 minhash <- minhash_generator(n = 1000, seed = 123456789)
 candidates <- textrank_candidates_lsh(x = terminology$lemma, 
-                                      sentence_id = terminology$sentence_id,
+                                      sentence_id = terminology$textrank_id,
                                       minhashFUN = minhash, 
                                       bands = 500)
 dim(candidates)
